@@ -141,7 +141,9 @@ The dict in the list contains three items:
             f.append(path)
         if entity_filter is not None:
             f.append(entity_filter)
-        mexpr = "+".join(f)
+        mexpr = None
+        if f:
+            mexpr = "+".join(f)
 
         log.debug("mexpr: %s" % mexpr)
 
@@ -681,7 +683,7 @@ Produce an EntityDescriptors set from a list of entities. Optional Name, cacheDu
                 schema().assertValid(t)
             except DocumentInvalid, ex:
                 log.debug(_e(ex.error_log))
-                raise MetadataException("XML schema validation failed")
+                raise MetadataException("XML schema validation failed: %s" % name)
         return t
 
     def error_set(self, url, title, ex):
